==> mailutils_0.6.1.orig.tar.gz: mailutils-0.6.1/mail/touch.c <==
/* GNU Mailutils -- a suite of utilities for electronic mail
   Copyright (C) 1999, 2001, 2005 Free Software Foundation, Inc.

   GNU Mailutils is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   GNU Mailutils is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with GNU Mailutils; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */

#include "mail.h"

/* tou[ch] [msglist]
   
   Touch the specified messages. If any message in msglist is not
   specifically deleted nor saved in a file, it shall be placed in the
   mbox upon normal termination. */

static int
touch0 (msgset_t *mspec, message_t msg, void *data)
{
  attribute_t attr = NULL;
  
  message_get_attribute (msg, &attr);
  if (!attribute_is_userflag (attr, MAIL_ATTRIBUTE_SAVED))
    {
      attribute_set_userflag (attr, MAIL_ATTRIBUTE_MBOXED);
      util_mark_read (msg);
    }
  
  cursor = mspec->msg_part[0];
}

int
mail_touch (int argc, char **argv)
{
  return util_foreach_msg (argc, argv, MSG_NODELETED, touch0, NULL);
  return mail_mbox (argc, argv);
}

==> mailutils-1.0.tar.gz: mailutils-1.0/mail/touch.c <==
/* GNU Mailutils -- a suite of utilities for electronic mail
   Copyright (C) 1999, 2001, 2005 Free Software Foundation, Inc.

   GNU Mailutils is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   GNU Mailutils is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with GNU Mailutils; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301 USA */

#include "mail.h"

/* tou[ch] [msglist]
   
   Touch the specified messages. If any message in msglist is not
   specifically deleted nor saved in a file, it shall be placed in the
   mbox upon normal termination. */

static int
touch0 (msgset_t *mspec, mu_message_t msg, void *data)
{
  mu_attribute_t attr = NULL;
  
  mu_message_get_attribute (msg, &attr);
  if (!mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_SAVED))
    {
      mu_attribute_set_userflag (attr, MAIL_ATTRIBUTE_MBOXED);
      util_mark_read (msg);
    }
  
  set_cursor (mspec->msg_part[0]);
  return 0;
}

int
mail_touch (int argc, char **argv)
{
  return util_foreach_msg (argc, argv, MSG_NODELETED, touch0, NULL);
  return mail_mbox (argc, argv);
}
